@@ -1,11 +1,12 @@
-"""
-The `pydantic_extra_types.coordinate` module provides the [`Latitude`][pydantic_extra_types.coordinate.Latitude],
+"""The `pydantic_extra_types.coordinate` module provides the [`Latitude`][pydantic_extra_types.coordinate.Latitude],
 [`Longitude`][pydantic_extra_types.coordinate.Longitude], and
 [`Coordinate`][pydantic_extra_types.coordinate.Coordinate] data types.
 """
 
+from __future__ import annotations
+
 from dataclasses import dataclass
-from typing import Any, ClassVar, Tuple, Type
+from typing import Any, ClassVar, Tuple
 
 from pydantic import GetCoreSchemaHandler
 from pydantic._internal import _repr
@@ -19,12 +20,14 @@ class Latitude(float):
     from pydantic import BaseModel
     from pydantic_extra_types.coordinate import Latitude
 
+
     class Location(BaseModel):
         latitude: Latitude
 
+
     location = Location(latitude=41.40338)
     print(location)
-    #> latitude=41.40338
+    # > latitude=41.40338
     ```
     """
 
@@ -32,7 +35,7 @@ class Latitude(float):
     max: ClassVar[float] = 90.00
 
     @classmethod
-    def __get_pydantic_core_schema__(cls, source: Type[Any], handler: GetCoreSchemaHandler) -> core_schema.CoreSchema:
+    def __get_pydantic_core_schema__(cls, source: type[Any], handler: GetCoreSchemaHandler) -> core_schema.CoreSchema:
         return core_schema.float_schema(ge=cls.min, le=cls.max)
 
 
@@ -44,12 +47,14 @@ class Longitude(float):
 
     from pydantic_extra_types.coordinate import Longitude
 
+
     class Location(BaseModel):
         longitude: Longitude
 
+
     location = Location(longitude=2.17403)
     print(location)
-    #> longitude=2.17403
+    # > longitude=2.17403
     ```
     """
 
@@ -57,7 +62,7 @@ class Longitude(float):
     max: ClassVar[float] = 180.00
 
     @classmethod
-    def __get_pydantic_core_schema__(cls, source: Type[Any], handler: GetCoreSchemaHandler) -> core_schema.CoreSchema:
+    def __get_pydantic_core_schema__(cls, source: type[Any], handler: GetCoreSchemaHandler) -> core_schema.CoreSchema:
         return core_schema.float_schema(ge=cls.min, le=cls.max)
 
 
@@ -76,11 +81,13 @@ class Coordinate(_repr.Representation):
 
     from pydantic_extra_types.coordinate import Coordinate
 
+
     class Location(BaseModel):
         coordinate: Coordinate
 
+
     location = Location(coordinate=(41.40338, 2.17403))
-    #> coordinate=Coordinate(latitude=41.40338, longitude=2.17403)
+    # > coordinate=Coordinate(latitude=41.40338, longitude=2.17403)
     ```
     """
 
@@ -90,7 +97,7 @@ class Coordinate(_repr.Representation):
     longitude: Longitude
 
     @classmethod
-    def __get_pydantic_core_schema__(cls, source: Type[Any], handler: GetCoreSchemaHandler) -> core_schema.CoreSchema:
+    def __get_pydantic_core_schema__(cls, source: type[Any], handler: GetCoreSchemaHandler) -> core_schema.CoreSchema:
         schema_chain = [
             core_schema.no_info_wrap_validator_function(cls._parse_str, core_schema.str_schema()),
             core_schema.no_info_wrap_validator_function(
@@ -123,18 +130,16 @@ class Coordinate(_repr.Representation):
             return value
         try:
             value = tuple(float(x) for x in value.split(','))
-        except ValueError:
+        except ValueError as e:
             raise PydanticCustomError(
                 'coordinate_error',
                 'value is not a valid coordinate: string is not recognized as a valid coordinate',
-            )
+            ) from e
         return ArgsKwargs(args=value)
 
     @classmethod
     def _parse_tuple(cls, value: Any, handler: core_schema.ValidatorFunctionWrapHandler) -> Any:
-        if not isinstance(value, tuple):
-            return value
-        return ArgsKwargs(args=handler(value))
+        return ArgsKwargs(args=handler(value)) if isinstance(value, tuple) else value
 
     def __str__(self) -> str:
         return f'{self.latitude},{self.longitude}'
