@@ -1,5 +1,4 @@
-"""
-The `pydantic_extra_types.mac_address` module provides functionality to parse and validate MAC addresses in different
+"""The MAC address module provides functionality to parse and validate MAC addresses in different
 formats, such as IEEE 802 MAC-48, EUI-48, EUI-64, or a 20-octet format.
 """
 
@@ -24,14 +23,24 @@ class MacAddress(str):
         mac_address: MacAddress
 
 
-    network = Network(mac_address="00:00:5e:00:53:01")
+    network = Network(mac_address='00:00:5e:00:53:01')
     print(network)
-    #> mac_address='00:00:5e:00:53:01'
+    # > mac_address='00:00:5e:00:53:01'
     ```
     """
 
     @classmethod
     def __get_pydantic_core_schema__(cls, source: type[Any], handler: GetCoreSchemaHandler) -> core_schema.CoreSchema:
+        """Return a Pydantic CoreSchema with the MAC address validation.
+
+        Args:
+            source: The source type to be converted.
+            handler: The handler to get the CoreSchema.
+
+        Returns:
+            A Pydantic CoreSchema with the MAC address validation.
+
+        """
         return core_schema.with_info_before_validator_function(
             cls._validate,
             core_schema.str_schema(),
@@ -39,22 +48,21 @@ class MacAddress(str):
 
     @classmethod
     def _validate(cls, __input_value: str, _: Any) -> str:
-        return cls.validate_mac_address(__input_value.encode())
-
-    @staticmethod
-    def validate_mac_address(value: bytes) -> str:
-        """
-        Validate a MAC Address from the provided byte value.
+        """Validate a MAC Address from the provided str value.
 
         Args:
-            value: The byte value representing the MAC address.
+            __input_value: The str value to be validated.
+            _: The source type to be converted.
 
         Returns:
             str: The parsed MAC address.
 
-        Raises:
-            PydanticCustomError: If the value is not a valid MAC address.
         """
+        return cls.validate_mac_address(__input_value.encode())
+
+    @staticmethod
+    def validate_mac_address(value: bytes) -> str:
+        """Validate a MAC Address from the provided byte value."""
         if len(value) < 14:
             raise PydanticCustomError(
                 'mac_address_len',
